@@ -785,4 +785,43 @@ def has_method(class_instance,method_name):
             return True
     return False
 
+def has_attr(class_instance,keys):
+    '''
+        Check if the class provided has an attribute matching a key.
+        
+        This is identical to calling "hasattr" except it accepts a list of keys and returns the matching one.
 
+        ----------
+
+        Arguments
+        -------------------------
+        `class_instance` {any}
+            The class to search within.
+            
+        `keys` {list,str}
+            The key or list of keys to search for.
+
+
+        Return {str|bool}
+        ----------------------
+        The matching attribute key, if it is found, False otherwise.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 07-11-2022 08:52:06
+        `memberOf`: dict_utils
+        `version`: 1.0
+        `method_name`: has_attr
+        * @xxx [07-11-2022 08:54:14]: documentation for has_attr
+    '''
+
+
+    keys = _lu.force_list(keys)
+    
+    
+    for key in keys:
+        if hasattr(class_instance,key):
+            return key
+        
+    return False
