@@ -3,6 +3,6 @@
 # pylint: disable=line-too-long
 
 
-import utils.drawio.drawing
+import utils.drawio.Drawing as drawing
 # import utils.drawio.diagram
 # import utils.drawio.nodeBase as NodeBase
