@@ -15,6 +15,7 @@
 '''
 
 import random as _random
+import exrex as _exrex
 import hashlib as _hashlib
 import time as _time
 import string as _string
@@ -56,6 +57,9 @@ def gen_variations(value):
     varis.append(screaming_snake_case)
     return varis
 
+def number(minimum=1,maximum=100):
+    return _random.randint(minimum,maximum)
+
 def boolean(bias=50):
     return _random.randint(1,100) <= bias
 
@@ -312,7 +316,7 @@ def url(bias=100):
         return faker().url()
     return None
 
-def abstract_name(**kwargs):
+def abstract_name(bias=100):
     '''
         Generate an abstract (non-human) name consisting of an adjective and a noun.
 
@@ -320,14 +324,11 @@ def abstract_name(**kwargs):
 
         Arguments
         -------------------------
-        `arg_name` {type}
-                arg_description
-
-        Keyword Arguments
-        -------------------------
         [`bias`=100] {int}
             The likelihood (0-100) of it returning an abstract name vs returning None
 
+            If bias = 100 it will always return an abstract_name and never None.
+
         Return {str|None}
         ----------------------
         The abstract name or None if the bias is provided.
@@ -341,7 +342,7 @@ def abstract_name(**kwargs):
         `method_name`: abstract_name
         * @xxx [06-03-2022 07:38:26]: documentation for abstract_name
     '''
-    bias = _obj.get_kwarg(['bias'], 100, (int), **kwargs)
+    # bias = _obj.get_kwarg(['bias'], 100, (int), **kwargs)
     if faker().boolean(bias):
         return f"{_rand_adjective()} {_rand_noun()}".title()
     return None
@@ -819,13 +820,88 @@ def male_first_last_name():
     fake = faker()
     return (fake.first_name_male(), fake.last_name())
 
-def gender()->str:
+def male_first_name():
+    fake = faker()
+    return fake.first_name_male()
+
+def female_first_name():
+    fake = faker()
+    return fake.first_name_female()
+
+def common_animal():
     '''
-        Randomly generate a gender "male" or "female"
+        Get a random common animal.
 
         ----------
 
 
+        Return {str}
+        ----------------------
+        The name of a random animal.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 07-21-2022 07:53:39
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: common_animal
+        * @xxx [07-21-2022 07:54:09]: documentation for common_animal
+    '''
+
+
+    return _rand_option(_ru.COMMON_ANIMALS)
+
+def threat():
+    '''
+        Randomly generate a shitty threat.
+
+        ----------
+
+
+        Return {str}
+        ----------------------
+        A random threat.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 07-21-2022 08:04:21
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: threat
+        * @xxx [07-21-2022 08:04:40]: documentation for threat
+    '''
+
+
+    exrex_threats = [
+        f"you (could|might|may|will) die (horribly|slowly|by drowning in (chipmunks|hamsters|chainsaws|ferrets|{common_animal()}))",
+        f"your (pets|family|friends|family and friends|loved ones) will be (haunted|eaten|stalked|starred at menacingly) by (snail|rabbit|kitten|{common_animal()}) ghosts",
+    ]
+    th = _rand_option(exrex_threats)
+    th = _rand_option(list(_exrex.generate(th)))
+    th = th.replace("__RANDOM_ANIMAL__",common_animal())
+    return th
+
+def gender(bias=100,return_int=False)->str:
+    '''
+        Randomly generate a gender "female", "male", "other"
+
+        ----------
+
+        Arguments
+        -------------------------
+        [`bias`=100] {int}
+            The likelihood (0-100) of it returning a gender vs returning None
+
+            If bias = 100 it will always return a gender and never None.
+
+        [`return_int`=False] {bool}
+            If True it will return the index of the option instead of the string:
+            - 0 = female
+            - 1 = male
+            - 2 = other
+
         Return {str}
         ----------------------
         The gender.
@@ -839,9 +915,18 @@ def gender()->str:
         `method_name`: gender
         * @xxx [06-04-2022 10:12:06]: documentation for gender
     '''
+    options = ["female","male","other"]
 
+    if return_int is False:
+        if faker().boolean(bias):
+            return _ru.option(options)
+    if return_int is True:
+        if faker().boolean(bias):
+            return _random.randint(0,len(options)-1)
+    return None
+
+    # return _ru.option(["male","female"])
 
-    return _ru.option(["male","female"])
 
 def user(**kwargs)->dict:
     '''
@@ -915,7 +1000,3 @@ def user(**kwargs)->dict:
     data['phone'] = fake.phone_number()
 
     return data
-
-
-
-
